#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib"
XML2_LIBS="-lxml2 -L/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -lz -L/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -llzma -lpthread -L/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -L/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -licui18n -licuuc -licudata -lm "
XML2_INCLUDEDIR="-I/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/include/libxml2 -I/tmp/build/80754af9/libxml2_1624477882915/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/include"
MODULE_VERSION="xml2-2.9.12"

